@@ -22,4 +22,9 @@ class IndicoInvalidConfigSetting(IndicoError):
 
 class IndicoNotFound(IndicoError):
     def __init__(self, cls):
-        super().__init__(f"Could not find {cls}")
\ No newline at end of file
+        super().__init__(f"Could not find {cls}")
+
+
+class IndicoAuthenticationFailed(IndicoError):
+    def __init__(self):
+        super().__init__("Failed to authenticate")
\ No newline at end of file
