@@ -1,11 +1,19 @@
+import pytest
 from indico.client import IndicoClient, IndicoConfig
 from indico.client.request import HTTPRequest, HTTPMethod, GraphQLRequest
+from indico.errors import IndicoAuthenticationFailed
 
 def test_http_request(indico):
     client = IndicoClient()
     response = client.call(HTTPRequest(method=HTTPMethod.GET, path="/auth/users/details"))
     assert "email" in response
 
+
+def test_bad_token(indico):
+    with pytest.raises(IndicoAuthenticationFailed):
+        client = IndicoClient(IndicoConfig(api_token="askldjflkasdjf"))
+
+
 def test_disable_cookie_domain(indico):
     client = IndicoClient(IndicoConfig(_disable_cookie_domain=True))
     assert client.config._disable_cookie_domain == True
